@@ -58,14 +58,14 @@ class DigiCubeServer:
         self.api.add_event_handler("startup", self._inner.onStartup)
         self.api.add_event_handler("shutdown", self._inner.onShutdown)
         self.api.add_middleware(SettingsMiddleware, settings=self.config, api=self.api)
-        self.api.add_middleware(UpdateTokenMiddleware, settings=self.config, api=self.api)
+        # self.api.add_middleware(UpdateTokenMiddleware, settings=self.config, api=self.api)
 
         endpoint.add_routes(self.api)
 
         @self.api.route("/user/bylogin/{data}")
         async def get_user_by_login(req: responder.Request, resp: responder.Response, *, data):
             if req.method == "get":
-                user = models.User.get_or_none(login=data)
+                user = await models.User.get_or_none(login=data)
                 if user is None:
                     resp.status_code = 404
                     resp.text = f"User with login {data} not found."
